==> dde-dock_5.4.7.orig.tar.xz: dde-dock-5.4.7/translations/dde-dock_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Přídavný modul %1 není slučitelný se systémem.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Nastavení Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Zapnout</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Nastavení Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 připojeno</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Připojuje se...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Vypnuto</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Přidat rozvržení klávesnice</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum a čas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 hodinový čas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 hodinový čas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Nastavení času</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Povolit síť</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Zakázat síť</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Nastavení sítě</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Opravdu chcete %1 položek smazat?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Tento krok nelze vrátit zpět</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Neznámé zařízení</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Neznámý svazek</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Odpojit vše</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Spouštěč</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Módní režim</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Účelný režim</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Vždy zobrazeno</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Vždy skryto</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Chytré skrývání</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Zásuvné moduly</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Víceúlohový pohled</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Zrušit ukotvení</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Vypnout drátové připojení</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Zapnout drátové připojení</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Vypnout bezdrátové připojení</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Zapnout bezdrátové připojení</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Zakázat síť</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Povolit síť</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Nastavení sítě</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Zařízení zakázáno</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Bezdrátové připojení: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Drátové připojení: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nepřipojeno</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Připojuje se</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Připojeno, ale bez přístupu k Internetu</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Síťový kabel odpojen</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrátová síť</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Drátová síť</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Připojení se nezdařilo</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Síť</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Drátová síť</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Drátová síť %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Na základní desce</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Napájení</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavení správy napájení</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Stav %1, %2 min zbývá</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Stav %1, %2 h %3 min zbývá</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Nabíjení %1, %2 min do úplného nabití</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Nabíjení %1, %2 h %3 min do úplného nabití</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Nabito</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacita %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Nabíjení: %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacita %1…</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacita %1, plně nabito</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Ukázat plochu</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Zrušit ukotvení</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Napájení</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Vypínání</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspat</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uspat na disk</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Uzamknout</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odhlašování se</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Přepnout účet</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavení správy napájení</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Zařízení</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Zrušit ztlumení</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Ztlumit</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Nastavení zvuku</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Hlasitost %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Koš</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Koš – %1 soubor</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Koš – %1 souborů</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Prázdný</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Oznamovací oblast panelu</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrátová síť</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Bezdrátová síť %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.86.1.orig.tar.xz: dde-dock-5.5.86.1/translations/dde-dock_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Přídavný modul %1 není slučitelný se systémem.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Režim letadlo</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Režim letadlo zapnut</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Zapnout</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Nastavení režimu letadlo</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Režim letadlo vypnut</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Režim letadlo</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Nastavení Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Zapnout</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Nastavení Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 připojeno</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Připojuje se...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Vypnuto</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Přidat rozvržení klávesnice</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum a čas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 hodinový čas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 hodinový čas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Nastavení času</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>neděle</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>pondělí</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sunday</source>
        <translation>neděle</translation>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Opravdu chcete %1 položek smazat?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Tento krok nelze vrátit zpět</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Neznámé zařízení</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Neznámý svazek</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Odpojit vše</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Spouštěč</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Ukončit náhradní režim</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Panel – náhradní režim</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Dok je v náhradním režimu – ukončete, aby se zobrazil správně</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Líbivý režim</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Účelný režim</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Vždy zobrazeno</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Vždy skryto</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Chytré skrývání</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Nastavení panelu</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Velikost </translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Více displejů </translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Oblast pluginu </translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Vyberte, které ikony se zobrazí v Docku </translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Módní režim </translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Efektivní režim </translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Režim </translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Umístění </translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Ponechat zobrazený</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Ponechat skrytý</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Chytré skrývání</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>Malý</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Velký</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Zobrazit panel</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Na obrazovce, kde je ukazovátko</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Pouze na hlavní obrazovce </translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Víceúlohový pohled</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Zrušit ukotvení</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Na základní desce</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Napájení</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavení správy napájení</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Stav %1, %2 min zbývá</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Stav %1, %2 h %3 min zbývá</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Nabíjení %1, %2 min do úplného nabití</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Nabíjení %1, %2 h %3 min do úplného nabití</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacita %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Nabíjení: %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacita %1…</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacita %1, plně nabito</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Panel</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Zobrazit panel</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Oblast zásuvného modulu</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Ukázat plochu</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Zrušit ukotvení</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Napájení</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Vypínání</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspat</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uspat na disk</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Uzamknout</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odhlašování se</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Přepnout účet</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavení správy napájení</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Hlasitost</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Zrušit ztlumení</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Ztlumit</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Nastavení zvuku</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Hlasitost %1</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Koš</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Koš – %1 soubor</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Koš – %1 souborů</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Přesunout do koše</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Prázdný</translation>
    </message>
</context>
</TS>
